==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/SeriesViewerManipulationEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerManipulationEventArgsDescription } from "./SeriesViewerManipulationEventArgsDescription";
/**
 * @hidden
 */
export let SeriesViewerManipulationEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SeriesViewerManipulationEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SeriesViewerManipulationEventArgsDescriptionMetadata.a == null) {
                SeriesViewerManipulationEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SeriesViewerManipulationEventArgsDescriptionMetadata.c(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
            }
            if (a.k(SeriesViewerManipulationEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsZoomPan", "Boolean");
            a.item("IsDragZoom", "Boolean");
        }
        static d(a) {
            SeriesViewerManipulationEventArgsDescriptionMetadata.b(a);
            a.ad("SeriesViewerManipulationEventArgs", () => new SeriesViewerManipulationEventArgsDescription());
            a.ac("SeriesViewerManipulationEventArgs", SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
    }
    SeriesViewerManipulationEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SeriesViewerManipulationEventArgsDescriptionMetadata, 'SeriesViewerManipulationEventArgsDescriptionMetadata');
    SeriesViewerManipulationEventArgsDescriptionMetadata.a = null;
    return SeriesViewerManipulationEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/SeriesViewerManipulationEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerManipulationEventArgsDescription } from "./SeriesViewerManipulationEventArgsDescription";
/**
 * @hidden
 */
export let SeriesViewerManipulationEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SeriesViewerManipulationEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SeriesViewerManipulationEventArgsDescriptionMetadata.a == null) {
                SeriesViewerManipulationEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SeriesViewerManipulationEventArgsDescriptionMetadata.c(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
            }
            if (a.k(SeriesViewerManipulationEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsZoomPan", "Boolean");
            a.item("IsDragZoom", "Boolean");
            a.item("IsDragSelect", "Boolean");
        }
        static d(a) {
            SeriesViewerManipulationEventArgsDescriptionMetadata.b(a);
            a.ae("SeriesViewerManipulationEventArgs", () => new SeriesViewerManipulationEventArgsDescription());
            a.ad("SeriesViewerManipulationEventArgs", SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
    }
    SeriesViewerManipulationEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SeriesViewerManipulationEventArgsDescriptionMetadata, 'SeriesViewerManipulationEventArgsDescriptionMetadata');
    SeriesViewerManipulationEventArgsDescriptionMetadata.a = null;
    return SeriesViewerManipulationEventArgsDescriptionMetadata;
})();
